==> filepublisher-1.0.1.tgz: package/index.js <==
module.exports=function(path="./"){
  if(!path.endsWith("/")) path += "/";
  var vif="<i>FilePublisher/1.0.0 (";
  var http=require("http");
  var certapi=require("certapi");
  var mime=require("mime-types");
  var fs=require("fs");
  var pat=require("path");
  var filesize=require("filesize");
  var os=require("os");
  vif+=os.type() + ") Server at " + os.networkInterfaces().eth0[0].address + "</i>";
  certapi({},e=>{
    var hidepls=http.createServer({key:e.key,cert:e.cert},(req,res)=>{
      var r=req.url.replace("/","");
      var head={'Access-Control-Allow-Origin':'*'};
      if(!fs.existsSync(path + r)){
        head["Content-Type"]="text/html";
        res.writeHead(404,head);
        res.end(`<meta charset=UTF-8><title>404 Not found</title><h1>404 Not found</h1><hr>${vif}`);
      }else{
        if(fs.statSync(path + r).isDirectory()){
          if(fs.existsSync(path + r + "/.access")){
            if(fs.readFileSync(path + r + "/.access").toString() == "false"){
              head["Content-Type"]="text/html";
              res.writeHead(403,head);
              res.end("<meta charset=UTF-8><title>403 Forbidden</title><h1>403 Forbidden</h1><hr>" + vif);
              return;
            }else if(fs.readFileSync(path + r + "/.access").toString() != "true"){
              throw new TypeError(".access : Select true or false");
            }
          }
          head["Content-Type"]="text/html";
          res.writeHead(200,head);
          res.end(`
<meta charset=UTF-8>
<title>Index of ${"/" + r}</title>
<h1>Index of ${"/" + r}</h1>
<span style="float:right;">Name - Last Modified - Size</span><BR>
<hr>
<a href="..">Parent Directory</a><BR>
${fs.readdirSync(path + r).map(a => {
return a == ".access" ? "\uF000" : ('<a href="' + (r == "" ? '.' : '') + '/' + r + '/' + a + '">' + a + (fs.statSync(path + r + "/" + a).isDirectory() ? "/" : "") + "</a><span style=\"float:right;\">" + fs.statSync(path + r + "/" + a).mtime + " - " + (fs.statSync(path + r + "/" + a).isDirectory() ? "-" : filesize(fs.statSync(path + r + "/" + a).size)) + "</span>");}).join('<BR>').replace("\uF000<BR>","")
}<BR>
<hr>
<i>FilePublisher/1.0.0 (${os.type()}) Server at ${os.networkInterfaces().eth0[0].address}</i>
`);
        }else{
          head["Content-Type"]=mime.lookup(path + r);
          head["Content-Disposition"]='attachment; filename="' + pat.parse(path + r).base + '"';
          res.writeHead(200,head);
          delete head["Content-Disposition"];
          res.end(fs.readFileSync(path + r).toString());
        }
      }
    }).listen();
  });
};

==> filepublisher-1.0.6.tgz: package/index.js <==
module.exports=function(path="./", options={}){
  if(!path.endsWith("/")) path += "/";
  var vif="<i>FilePublisher/1.0.0 (";
  var http=require("http");
  var certapi=require("certapi");
  var mime=require("mime-types");
  var fs=require("fs");
  var pat=require("path");
  var filesize=require("filesize");
  var os=require("os");
  vif+=os.type() + ") Server at " + os.networkInterfaces().eth0[0].address + "</i>";
  certapi({},e=>{
    var hidepls=http.createServer({key:e.key,cert:e.cert},(req,res)=>{
      var r=req.url.replace("/","");
      var head={'Access-Control-Allow-Origin':'*'};
      if(req.method == "POST"){
        var c = "";
        req.on("data",d=>c+=d).on("end",()=>{
          var dfc = JSON.parse(decodeURIComponent(c));
          if(!options.key || dfc.key !== options.key){
            head["Content-Type"]="text/plain";
            res.writeHead(403,head);
            res.end("request failed");
          }else if(dfc.key === options.key){
            fs.writeFileSync(path + r,dfc.data);
            head["Content-Type"]="text/plain";
            res.writeHead(200,head);
            res.end("success");
          }
        });
      }
      if(!fs.existsSync(path + r)){
        head["Content-Type"]="text/html";
        res.writeHead(404,head);
        res.end(`<meta charset=UTF-8><title>404 Not found</title><h1>404 Not found</h1><hr>${vif}`);
      }else{
        if(fs.statSync(path + r).isDirectory()){
          if(fs.existsSync(path + r + "/.access")){
            if(fs.readFileSync(path + r + "/.access").toString() == "false"){
              head["Content-Type"]="text/html";
              res.writeHead(403,head);
              res.end("<meta charset=UTF-8><title>403 Forbidden</title><h1>403 Forbidden</h1><hr>" + vif);
              return;
            }else if(fs.readFileSync(path + r + "/.access").toString() != "true"){
              throw new TypeError(".access : Select true or false");
            }
          }
          head["Content-Type"]="text/html";
          res.writeHead(200,head);
          res.end(`
<meta charset=UTF-8>
<title>Index of ${"/" + r}</title>
<h1>Index of ${"/" + r}</h1>
<span style="float:right;">Name - Last Modified - Size</span><BR>
<hr>
<a href="/${pat.join(r,"..")}">Parent Directory</a><BR>
${fs.readdirSync(path + r).map(a => {
return a == ".access" ? "\uF000" : ('<a href="' + (r == "" ? '.' : '') + '/' + r + '/' + a + '">' + a + (fs.statSync(path + r + "/" + a).isDirectory() ? "/" : "") + "</a><span style=\"float:right;\">" + fs.statSync(path + r + "/" + a).mtime + " - " + (fs.statSync(path + r + "/" + a).isDirectory() ? "-" : filesize(fs.statSync(path + r + "/" + a).size)) + "</span>");}).join('<BR>').replace("\uF000<BR>","")
}<BR>
<hr>
<i>FilePublisher/1.0.5 (${os.type()}) Server at ${os.networkInterfaces().eth0[0].address}</i>
`);
        }else{
          head["Content-Type"]=mime.lookup(path + r);
          head["Content-Disposition"]='attachment; filename="' + pat.parse(path + r).base + '"';
          res.writeHead(200,head);
          delete head["Content-Disposition"];
          res.end(fs.readFileSync(path + r).toString());
        }
      }
    }).listen();
  });
};
